::: beignet.add_polynomial
::: beignet.differentiate_polynomial
::: beignet.divide_polynomial
::: beignet.evaluate_polynomial
::: beignet.evaluate_polynomial_2d
::: beignet.evaluate_polynomial_3d
::: beignet.evaluate_polynomial_cartesian_2d
::: beignet.evaluate_polynomial_cartesian_3d
::: beignet.evaluate_polynomial_from_roots
::: beignet.fit_polynomial
::: beignet.integrate_polynomial
::: beignet.linear_polynomial
::: beignet.multiply_polynomial
::: beignet.multiply_polynomial_by_x
::: beignet.polynomial_companion
::: beignet.polynomial_domain
::: beignet.polynomial_from_roots
::: beignet.polynomial_one
::: beignet.polynomial_power
::: beignet.polynomial_roots
::: beignet.polynomial_to_chebyshev_polynomial
::: beignet.polynomial_to_laguerre_polynomial
::: beignet.polynomial_to_legendre_polynomial
::: beignet.polynomial_to_physicists_hermite_polynomial
::: beignet.polynomial_to_probabilists_hermite_polynomial
::: beignet.polynomial_vandermonde
::: beignet.polynomial_vandermonde_2d
::: beignet.polynomial_vandermonde_3d
::: beignet.polynomial_x
::: beignet.polynomial_zero
::: beignet.subtract_polynomial
::: beignet.trim_polynomial_coefficients
